@@ -14,6 +14,7 @@
 #' @importFrom magrittr "%>%"
 #' @importFrom formula.tools lhs
 #' @importFrom formula.tools rhs
+#' @importFrom dplyr all_of
 #' @importFrom dplyr group_vars
 #' @importFrom dplyr select
 #' @importFrom dplyr summarize
@@ -55,10 +56,11 @@ get_correlation <- function(data, formula, na.rm = FALSE, ...) {
   # variables)
   if (length(grouping_variables) == 0) {
     correlation <- data %>%
-      select(outcome_variable, explanatory_variable)
+      select(all_of(outcome_variable), all_of(explanatory_variable))
   } else {
     correlation <- data %>%
-      select(outcome_variable, explanatory_variable, grouping_variables)
+      select(all_of(outcome_variable), all_of(explanatory_variable), 
+             all_of(grouping_variables))
   }
 
   # handle missing data
